@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client::Scroll;
 # ABSTRACT: A MetaCPAN::Client scroller
-$MetaCPAN::Client::Scroll::VERSION = '2.034000';
+$MetaCPAN::Client::Scroll::VERSION = '2.035000';
 use Moo;
 use Carp;
 use Ref::Util qw< is_hashref >;
@@ -96,10 +96,15 @@ sub BUILDARGS {
 
     # read response content --> object params
 
-    $args{_id}     = $content->{_scroll_id};
-    $args{total}   = $content->{hits}{total};
-    $args{_buffer} = $content->{hits}{hits};
-    $args{_remaining} = $content->{hits}{total};
+    my $total = is_hashref($content->{hits}{total})
+        ? $content->{hits}{total}{value}
+        : $content->{hits}{total};
+
+    $args{_remaining} = $total;
+    $args{total}      = $total;
+
+    $args{_id}        = $content->{_scroll_id};
+    $args{_buffer}    = $content->{hits}{hits};
 
     $args{aggregations} = $content->{aggregations}
         if $content->{aggregations} and is_hashref( $content->{aggregations} );
@@ -182,7 +187,7 @@ MetaCPAN::Client::Scroll - A MetaCPAN::Client scroller
 
 =head1 VERSION
 
-version 2.034000
+version 2.035000
 
 =head1 METHODS
 
